@@ -6,10 +6,13 @@ from braintree.signature_service import SignatureService
 from braintree.util.crypto import Crypto
 from braintree import exceptions
 
+
 class ClientToken(object):
 
     @staticmethod
-    def generate(params={}, gateway=None):
+    def generate(params=None, gateway=None):
+        if params is None:
+            params = {}
         if gateway is None:
             gateway = Configuration.gateway().client_token
 
